@@ -4,7 +4,7 @@ Main interface for backup-gateway service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_backup_gateway import (
         BackupGatewayClient,
         Client,
@@ -13,10 +13,8 @@ Usage::
         ListVirtualMachinesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: BackupGatewayClient = boto3.client("backup-gateway")
-    session_client: BackupGatewayClient = session.client("backup-gateway")
+    session = Session()
+    client: BackupGatewayClient = session.client("backup-gateway")
 
     list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
     list_hypervisors_paginator: ListHypervisorsPaginator = client.get_paginator("list_hypervisors")
